@@ -82,17 +82,9 @@ If anything goes wrong, then either function will return C<undef>.
 
 makeashorterlink, makealongerlink
 
-=head1 BUGS, REQUESTS, COMMENTS
+=head1 SUPPORT, LICENSE, THANKS and SUCH
 
-Please report any requests, suggestions or bugs via the system at
-L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
-This makes it much easier for me to track things and thus means
-your problem is less likely to be neglected.
-
-=head1 THANKS
-
-Ask Bjoern Hansen for providing both Metamark.net
-and advice on the module.
+See the main L<WWW::Shorten> docs.
 
 =head1 AUTHOR
 
